@@ -243,6 +243,15 @@ class JsonObject:
                 return cls.parse(req.text)
         return None
 
+    def __dataframe_values__(self):
+        return [v.to_dataframe() if isinstance(v, JsonList,JsonObject) else v for v in self.get_values()]
+
+    def to_dataframe(self):
+        from pandas import DataFrame
+        columns = self.get_columns()
+        return DataFrame(self.__dataframe_values__(), columns=columns)
+
+
 
 class SortOrder:
     Ascending = 0
